@@ -13,6 +13,7 @@ class FiberDynamicFields(InternetDynamicFields):
             self._df_previous_contract_pon(),
             self._df_previous_contract_fiber_speed(),
             self._activation_notes(),
+            self._df_mobile_pack_contracts(),
         ]
 
     def _activation_notes(self):
@@ -26,3 +27,9 @@ class FiberDynamicFields(InternetDynamicFields):
             name="velocitatSollicitadaContracteAnteriorCU",
             value=self.service_data.previous_contract_fiber_speed
         )
+
+    def _df_mobile_pack_contracts(self):
+        return DynamicField(
+            name="OdooMobileContractRefRelacionats",
+            value=self.service_data.mobile_pack_contracts,
+        )
