@@ -6,7 +6,7 @@ class MobileData:
         has_sim, type, previous_owner_vat, previous_owner_name,
         previous_owner_surname, previous_provider, product, delivery_street,
         delivery_city, delivery_zip_code, delivery_state, activation_notes="",
-        notes="", is_pack=False
+        notes="", is_grouped_with_fiber=False
     ):
         self.order_id = order_id
         self.phone_number = phone_number
@@ -27,4 +27,4 @@ class MobileData:
         self.delivery_state = delivery_state
         self.activation_notes = activation_notes
         self.notes = notes
-        self.is_pack = is_pack
+        self.is_grouped_with_fiber = is_grouped_with_fiber
