@@ -7,6 +7,7 @@ class MobileDynamicFields(ProvisionDynamicFields):
 
     def _build_specific_dynamic_fields(self):
         return [
+            self._order_id(),
             self._line(),
             self._icc_sc(),
             self._icc_donor(),
@@ -17,16 +18,18 @@ class MobileDynamicFields(ProvisionDynamicFields):
             self._zip(),
             self._city(),
             self._subdivision(),
-            self._has_sim(),
             self._sim_received(),
-            self._activation_notes(),
             self._send_sim_type(),
+            self._activation_notes(),
             self._delivery_street(),
             self._delivery_zip_code(),
             self._delivery_city(),
             self._delivery_state(),
         ]
 
+    def _order_id(self):
+        return DynamicField("IDpeticio", self.service_data.order_id)
+
     def _line(self):
         return DynamicField("liniaMobil", self.service_data.phone_number)
 
@@ -54,9 +57,6 @@ class MobileDynamicFields(ProvisionDynamicFields):
             value=self.service_data.previous_owner_vat
         )
 
-    def _has_sim(self):
-        return DynamicField("noCobrarSIM", self.service_data.has_sim)
-
     def _activation_notes(self):
         return DynamicField(
             name="consideracionsActivacio",
@@ -64,13 +64,11 @@ class MobileDynamicFields(ProvisionDynamicFields):
         )
 
     def _sim_received(self):
-        return DynamicField("SIMrebuda", self.service_data.has_sim)
+        sim_recieved = "1" if self.service_data.has_sim else "0"
+        return DynamicField("SIMrebuda", sim_recieved)
 
     def _send_sim_type(self):
-        if self.service_data.has_sim:
-            return DynamicField("tipusEnviamentSIM", "None")
-        else:
-            return DynamicField("tipusEnviamentSIM", "CH_SC_OSO_SIM")
+        return DynamicField("tipusEnviamentSIM", "CH_SC_OSO_SIM")
 
     def _street(self):
         return DynamicField("nomVia", self.customer_data.street)
