@@ -27,7 +27,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'product',
             'notes',
             'has_sim',
-            'is_pack',
+            'is_grouped_with_fiber',
             'activation_notes',
             'delivery_street',
             'delivery_city',
@@ -80,7 +80,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'product',
             'notes',
             'has_sim',
-            'is_pack',
+            'is_grouped_with_fiber',
             'activation_notes',
             'delivery_street',
             'delivery_city',
@@ -99,7 +99,8 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'subdivision'])
 
         mobile_data.service_type = 'mobile'
-        mobile_data.is_pack = True
+        mobile_data.type = "portability"
+        mobile_data.is_grouped_with_fiber = True
 
         otrs_process_ticket = Mock(spec=['id'])
         otrs_process_ticket.id = 234
@@ -174,41 +175,44 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
 
     @patch('otrs_somconnexio.otrs_models.provision_ticket.OTRSClient')
     def test_create_fiber_ticket_factory(self, MockOTRSClient):
-        service_data = Mock(spec=[
-            'order_id',
-            'previous_contract_pon',
-            'previous_contract_fiber_speed',
-            'previous_contract_address',
-            'previous_contract_phone',
-            'type',
-            'iban',
-            'email',
-            'phone_number',
-            'previous_provider',
-            'previous_owner_name',
-            'previous_owner_surname',
-            'previous_owner_vat',
-            'previous_service',
-            'service_address',
-            'service_city',
-            'service_zip',
-            'service_subdivision',
-            'service_subdivision_code',
-            'shipment_address',
-            'shipment_city',
-            'shipment_zip',
-            'shipment_subdivision',
-            'notes',
-            'activation_notes',
-            'adsl_coverage',
-            'mm_fiber_coverage',
-            'vdf_fiber_coverage',
-            'orange_fiber_coverage',
-            'type',
-            'product',
-            'previous_internal_provider',
-        ])
-        customer_data = Mock(spec=['id', 'first_name', 'name', 'vat_number', 'phone'])
+        service_data = Mock(
+            spec=[
+                "order_id",
+                "previous_contract_pon",
+                "previous_contract_fiber_speed",
+                "previous_contract_address",
+                "previous_contract_phone",
+                "type",
+                "iban",
+                "email",
+                "phone_number",
+                "previous_provider",
+                "previous_owner_name",
+                "previous_owner_surname",
+                "previous_owner_vat",
+                "previous_service",
+                "service_address",
+                "service_city",
+                "service_zip",
+                "service_subdivision",
+                "service_subdivision_code",
+                "shipment_address",
+                "shipment_city",
+                "shipment_zip",
+                "shipment_subdivision",
+                "notes",
+                "activation_notes",
+                "adsl_coverage",
+                "mm_fiber_coverage",
+                "vdf_fiber_coverage",
+                "orange_fiber_coverage",
+                "type",
+                "product",
+                "previous_internal_provider",
+                "mobile_pack_contracts",
+            ]
+        )
+        customer_data = Mock(spec=["id", "first_name", "name", "vat_number", "phone"])
 
         service_data.service_type = 'fiber'
 
