@@ -32,7 +32,7 @@ class ADSLDataTestCase(unittest.TestCase):
             mm_fiber_coverage=None,
             vdf_fiber_coverage=None,
             orange_fiber_coverage=None,
-            change_address="no",
+            type="location_change",
             landline_phone_number="landline_phone_number",
             product="product"
         )
