@@ -3,7 +3,7 @@ import unittest
 from mock import Mock, patch
 
 from otrs_somconnexio.otrs_models.adsl_ticket import ADSLTicket
-from otrs_somconnexio.otrs_models.configurations.adsl_ticket import ADSLTicketConfiguration
+from otrs_somconnexio.otrs_models.configurations.provision.adsl_ticket import ADSLTicketConfiguration
 
 
 class ADSLTicketTestCase(unittest.TestCase):
