@@ -38,7 +38,8 @@ class FiberDataTestCase(unittest.TestCase):
             previous_contract_address="Old street",
             previous_contract_phone="62626826",
             previous_contract_fiber_speed="100Mb",
-            previous_contract_pon="VDF0001"
+            previous_contract_pon="VDF0001",
+            mobile_pack_contracts="12345",
         )
 
         self.assertIsInstance(fiber_data, FiberData)
