@@ -18,45 +18,50 @@ def dynamic_fields_to_dct(dynamic_fields):
 
 class FiberDynamicFieldsTestCase(unittest.TestCase):
     def setUp(self):
-        self.customer_data = Mock(spec=[
-            'first_name',
-            'name',
-            'vat_number',
-            'phone',
-        ])
-        self.service_data = Mock(spec=[
-            'order_id',
-            'previous_contract_address',
-            'previous_contract_phone',
-            'previous_contract_pon',
-            'previous_contract_fiber_speed',
-            'iban',
-            'email',
-            'phone_number',
-            'service_address',
-            'service_city',
-            'service_zip',
-            'service_subdivision',
-            'service_subdivision_code',
-            'shipment_address',
-            'shipment_city',
-            'shipment_zip',
-            'shipment_subdivision',
-            'previous_service',
-            'previous_provider',
-            'previous_owner_vat',
-            'previous_owner_name',
-            'previous_owner_surname',
-            'notes',
-            'activation_notes',
-            'adsl_coverage',
-            'mm_fiber_coverage',
-            'vdf_fiber_coverage',
-            'orange_fiber_coverage',
-            'type',
-            'product',
-            'previous_internal_provider',
-        ])
+        self.customer_data = Mock(
+            spec=[
+                "first_name",
+                "name",
+                "vat_number",
+                "phone",
+            ]
+        )
+        self.service_data = Mock(
+            spec=[
+                "order_id",
+                "previous_contract_address",
+                "previous_contract_phone",
+                "previous_contract_pon",
+                "previous_contract_fiber_speed",
+                "iban",
+                "email",
+                "phone_number",
+                "service_address",
+                "service_city",
+                "service_zip",
+                "service_subdivision",
+                "service_subdivision_code",
+                "shipment_address",
+                "shipment_city",
+                "shipment_zip",
+                "shipment_subdivision",
+                "previous_service",
+                "previous_provider",
+                "previous_owner_vat",
+                "previous_owner_name",
+                "previous_owner_surname",
+                "notes",
+                "activation_notes",
+                "adsl_coverage",
+                "mm_fiber_coverage",
+                "vdf_fiber_coverage",
+                "orange_fiber_coverage",
+                "type",
+                "product",
+                "previous_internal_provider",
+                "mobile_pack_contracts",
+            ]
+        )
 
         self.fiber_otrs_process_id = "FiberProcessID"
         self.fiber_otrs_activity_id = "FiberActivityID"
@@ -555,15 +560,33 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["proveidorPreviCU"], "SC-MM")
 
-    def test_activivation_notes_field(self):
+    def test_activation_notes_field(self):
         self.service_data.activation_notes = "text text text"
 
         dynamic_fields = FiberDynamicFields(
             self.service_data,
             self.customer_data,
             self.fiber_otrs_process_id,
-            self.fiber_otrs_activity_id
+            self.fiber_otrs_activity_id,
         ).all()
 
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["consideracionsActivacio2"], "text text text")
+        self.assertEqual(
+            dynamic_fields_dct["consideracionsActivacio2"], "text text text"
+        )
+
+    def test_mobile_pack_contracts_field(self):
+        self.service_data.mobile_pack_contracts = "3456,12345"
+
+        dynamic_fields = FiberDynamicFields(
+            self.service_data,
+            self.customer_data,
+            self.fiber_otrs_process_id,
+            self.fiber_otrs_activity_id,
+        ).all()
+
+        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
+        self.assertEqual(
+            dynamic_fields_dct["OdooMobileContractRefRelacionats"],
+            self.service_data.mobile_pack_contracts,
+        )
