@@ -3,7 +3,7 @@ import unittest
 from mock import Mock, patch
 
 from otrs_somconnexio.otrs_models.fiber_ticket import FiberTicket
-from otrs_somconnexio.otrs_models.configurations.fiber_ticket import FiberTicketConfiguration
+from otrs_somconnexio.otrs_models.configurations.provision.fiber_ticket import FiberTicketConfiguration
 
 
 class FiberTicketTestCase(unittest.TestCase):
@@ -63,46 +63,51 @@ class FiberTicketTestCase(unittest.TestCase):
 
     @patch('otrs_somconnexio.otrs_models.provision_ticket.OTRSClient')
     def test_create(self, MockOTRSClient):
-        customer_data = Mock(spec=[
-            'id',
-            'phone',
-            'first_name',
-            'name',
-            'vat_number',
-        ])
-        service_data = Mock(spec=[
-            'order_id',
-            'previous_contract_address',
-            'previous_contract_phone',
-            'previous_contract_pon',
-            'previous_contract_fiber_speed',
-            'iban',
-            'email',
-            'previous_service',
-            'phone_number',
-            'previous_provider',
-            'previous_owner_vat',
-            'previous_owner_name',
-            'previous_owner_surname',
-            'service_address',
-            'service_city',
-            'service_zip',
-            'service_subdivision',
-            'service_subdivision_code',
-            'shipment_address',
-            'shipment_city',
-            'shipment_zip',
-            'shipment_subdivision',
-            'notes',
-            'activation_notes',
-            'adsl_coverage',
-            'mm_fiber_coverage',
-            'vdf_fiber_coverage',
-            'orange_fiber_coverage',
-            'type',
-            'product',
-            'previous_internal_provider',
-        ])
+        customer_data = Mock(
+            spec=[
+                "id",
+                "phone",
+                "first_name",
+                "name",
+                "vat_number",
+            ]
+        )
+        service_data = Mock(
+            spec=[
+                "order_id",
+                "previous_contract_address",
+                "previous_contract_phone",
+                "previous_contract_pon",
+                "previous_contract_fiber_speed",
+                "iban",
+                "email",
+                "previous_service",
+                "phone_number",
+                "previous_provider",
+                "previous_owner_vat",
+                "previous_owner_name",
+                "previous_owner_surname",
+                "service_address",
+                "service_city",
+                "service_zip",
+                "service_subdivision",
+                "service_subdivision_code",
+                "shipment_address",
+                "shipment_city",
+                "shipment_zip",
+                "shipment_subdivision",
+                "notes",
+                "activation_notes",
+                "adsl_coverage",
+                "mm_fiber_coverage",
+                "vdf_fiber_coverage",
+                "orange_fiber_coverage",
+                "type",
+                "product",
+                "previous_internal_provider",
+                "mobile_pack_contracts",
+            ]
+        )
 
         mock_otrs_client = Mock(spec=['create_otrs_process_ticket'])
         mock_otrs_client.create_otrs_process_ticket.return_value.id = 123
