@@ -3,11 +3,11 @@ import unittest
 from mock import Mock, patch
 
 from otrs_somconnexio.otrs_models.mobile_ticket import MobilePausedTicket
-from otrs_somconnexio.otrs_models.configurations.mobile_ticket import (
+from otrs_somconnexio.otrs_models.configurations.provision.mobile_ticket import (
     MobileTicketConfiguration, MobileTicketPausedConfiguration)
 
 
-class MobileTicketTestCase(unittest.TestCase):
+class MobileTicketPausedTestCase(unittest.TestCase):
 
     @patch('otrs_somconnexio.otrs_models.provision_ticket.Ticket')
     def test_build_mobile_paused_ticket(self, MockTicket):
