@@ -3,7 +3,7 @@ import unittest
 from mock import Mock, patch
 
 from otrs_somconnexio.otrs_models.mobile_ticket import MobileTicket
-from otrs_somconnexio.otrs_models.configurations.mobile_ticket import (
+from otrs_somconnexio.otrs_models.configurations.provision.mobile_ticket import (
     MobileTicketConfiguration, MobileTicketPausedConfiguration)
 
 
